def string(clazz):
    '''
    根绝 field 自动生成 class 的 __str__
    :param clazz: 类
    :return: clazz
    '''
    def __str__(self):
        return '%s(%s)' % (
            type(self).__name__,
            ', '.join('%s=%s' % item for item in vars(self).items())
        )
    clazz.__str__ = __str__
    return clazz




from unittest import TestCase

from suger import csv


@csv
class MockData:
    def __init__(self, name, age):
        self.name = name
        self.age = age
        self.csv = ''




class Test(TestCase):
    def test_csv(self):
        data = MockData(name='neko', age=18)

        print(data.csv_str())
        print(data.csv_format())



def csv(clazz):
    '''
    根绝 field 自动生成 csv, 赋值到 class 的 __str__ 来输出
    :param clazz: 类
    :return: clazz
    '''

    def csv_str(self):
        return '%s' % (
            ','.join(
                # 元组 (key, value)
                '%s' % item[1] for item in vars(self).items()
            )
        )

    def csv_format(self):
        return '%s' % (
            ','.join(
                '%s' % item[0] for item in vars(self).items()
            )
        )

    clazz.csv_str = csv_str
    clazz.csv_format = csv_format

    return clazz



class ObjectUtils:

    @staticmethod
    def isNull(obj) -> bool:
        return obj is None

    @staticmethod
    def isNotNull(obj) -> bool:
        return not (obj is None)

    @staticmethod
    def defaultIfNull(obj, defaultObj) -> object:
        """
        如果 obj 为 None，则返回 default；否则返回 obj。
        """
        return defaultObj if obj is None else obj

    @staticmethod
    def equals(obj1, obj2) -> bool:
        """
        判断 obj1 是否等于 obj2，如果 obj1 和 obj2 均为 None，则返回 True。
        """
        if obj1 is None and obj2 is None:
            return True
        elif obj1 is None or obj2 is None:
            return False
        else:
            return obj1 == obj2

    @staticmethod
    def hashCode(obj) -> int:
        """
        返回 obj 的哈希值，如果 obj 为 None，则返回 0。
        """
        return 0 if obj is None else hash(obj)



from unittest import TestCase

from suger import string


@string
class MockData:
    def __init__(self, age):
        self.age = age


class Test(TestCase):
    def test_string(self):
        data = MockData(18)

        target_str = "MockData(age=18)"
        self.assertEqual(data.__str__(), target_str, "not equals string")
